==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Sections/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Strona gotowa do druku");
define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_COMESFROM","Artyku jest z");
define("_THEURL","Adres tego artykuu to:");
define("_SECWELCOME","Witamy w sekcjach specjalnych na");
define("_YOUCANFIND","Tu moesz znale kilka ciekawych artykuw nie umieszczonych na stronie gwnej.");
define("_THISISSEC","To jest sekcja");
define("_FOLLOWINGART","Poniej s artykuy opublikowane w tej sekcji.");
define("_SECRETURN","Powrt do indeksu sekcji");
define("_TOTALWORDS","razem sw w tym tekcie");
define("_BACKTO","Powrt do");
define("_SECINDEX","Indeks sekcji");
define("_PAGE","Strona");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Sections/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Strona gotowa do druku");
define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_COMESFROM","Artyku jest z");
define("_THEURL","Adres tego artykuu to:");
define("_SECWELCOME","Witamy w sekcjach specjalnych na");
define("_YOUCANFIND","Tu moesz znale kilka ciekawych artykuw nie umieszczonych na stronie gwnej.");
define("_THISISSEC","To jest sekcja");
define("_FOLLOWINGART","Poniej s artykuy opublikowane w tej sekcji.");
define("_SECRETURN","Powrt do indeksu sekcji");
define("_TOTALWORDS","razem sw w tym tekcie");
define("_BACKTO","Powrt do");
define("_SECINDEX","Indeks sekcji");
define("_PAGE","Strona");

?>
